@@ -301,7 +301,7 @@ def resolve_ami(component_params, component, image, imagebranch, branch, git):
                 job = re.sub(r'\W', '_', image_params["JOB_NAME"])
             else:
                 prefix = ""
-                prefix = image_params["JENKINS_JOB_PREFIX"]
+                prefix = image_params["BUILD_JOB_PREFIX"]
                 job = prefix + "_" + component + "_bake"
                 if image:
                     job = job + "_" + image
@@ -326,8 +326,8 @@ def resolve_ami(component_params, component, image, imagebranch, branch, git):
                 repl_suffix += "_" + image
             if not image_params:
                 image_params = load_parameters(component=component, image=image, branch=imagebranch, git=git)
-            this_branch_prefix = re.sub(r'\W', '_', component_params["JENKINS_JOB_PREFIX"] + "_")
-            image_branch_prefix = re.sub(r'\W', '_', image_params["JENKINS_JOB_PREFIX"] + "_")
+            this_branch_prefix = re.sub(r'\W', '_', component_params["BUILD_JOB_PREFIX"] + "_")
+            image_branch_prefix = re.sub(r'\W', '_', image_params["BUILD_JOB_PREFIX"] + "_")
             job = lreplace(image_branch_prefix, this_branch_prefix, job)
             job = rreplace(suffix, repl_suffix, job)
             images = get_images(job)
@@ -376,7 +376,7 @@ def load_parameters(component=None, stack=None, serverless=None, docker=None, im
         prefix = ""
         if current_branch != branch:
             prefix = git.export_branch(branch) + os.sep
-        files = [prefix + "infra.properties", prefix + "infra-" + branch + ".properties"]
+        files = [prefix + "branch.properties", prefix + branch + ".properties", prefix + "infra.properties", prefix + "infra-" + branch + ".properties"]
         if component:
             files.append(prefix + component + os.sep + "infra.properties")
             files.append(prefix + component + os.sep + "infra-" + branch + ".properties")
@@ -441,14 +441,21 @@ def load_parameters(component=None, stack=None, serverless=None, docker=None, im
             ret["ORIG_STACK_NAME"] = os.environ["ORIG_STACK_NAME"]
             if "STACK_NAME" not in ret:
                 ret["STACK_NAME"] = component + "-" + ret["ORIG_STACK_NAME"] + "-" + ret["paramEnvId"]
+        if docker and "NEEDS_DOCKER" not in ret:
+            ret["NEEDS_DOCKER"] = "y"
         for k, v in list(os.environ.items()):
             if k.startswith("ORIG_") and k.endswith("_NAME"):
                 ret[k] = v
         if "ORIG_DOCKER_NAME" in os.environ:
             if "DOCKER_NAME" not in ret:
                 ret["DOCKER_NAME"] = component + "/" + ret["paramEnvId"] + "-" + ret["ORIG_DOCKER_NAME"]
+        if "BUILD_JOB_PREFIX" not in ret:
+            if "JENKINS_JOB_PREFIX" in ret:
+                ret["BUILD_JOB_PREFIX"] = ret["JENKINS_JOB_PREFIX"]
+            else:
+                ret["BUILD_JOB_PREFIX"] = "ndt" + ret["paramEnvId"]
         if "JENKINS_JOB_PREFIX" not in ret:
-            ret["JENKINS_JOB_PREFIX"] = "ndt" + ret["paramEnvId"]
+            ret["JENKINS_JOB_PREFIX"] = ret["BUILD_JOB_PREFIX"]
         parameters[params_key] = ret
         return ret
 
@@ -815,13 +822,18 @@ def _check_refs(data, templateFile, path, templateParams, resolveRefs):
     return data
 
 
-def import_scripts(data, basefile):
+def import_scripts(data, basefile, extra_parameters={}):
     global gotImportErrors
     gotImportErrors = False
-
-    data = expand_vars(data, _get_params(data, basefile), None, [])
-    data = _preprocess_template(data, data, basefile, "", _get_params(data, basefile))
-    data = _check_refs(data, basefile, "", _get_params(data, basefile), False)
+    params = _get_params(data, basefile)
+    params.update(extra_parameters)
+    data = expand_vars(data, params, None, [])
+    params = _get_params(data, basefile)
+    params.update(extra_parameters)
+    data = _preprocess_template(data, data, basefile, "", params)
+    params = _get_params(data, basefile)
+    params.update(extra_parameters)
+    data = _check_refs(data, basefile, "", params, False)
     if gotImportErrors:
         sys.exit(1)
     return data
@@ -905,7 +917,7 @@ def extract_scripts(data, prefix, path=""):
 # simple apis
 
 
-def yaml_to_dict(yaml_file_to_convert, merge=[]):
+def yaml_to_dict(yaml_file_to_convert, merge=[], extra_parameters={}):
     data = OrderedDict()
     with open(yaml_file_to_convert) as yaml_file:
         data = yaml_load(yaml_file)
@@ -917,7 +929,7 @@ def yaml_to_dict(yaml_file_to_convert, merge=[]):
         merge_data = OrderedDict()
         merge_data['Fn::Merge'] = merge
         data = merge_data
-    data = import_scripts(data, yaml_file_to_convert)
+    data = import_scripts(data, yaml_file_to_convert, extra_parameters=extra_parameters)
     _patch_launchconf(data)
     return data
 
