@@ -52,7 +52,7 @@ from n_utils.mfa_utils import mfa_add_token, mfa_delete_token, mfa_generate_code
     mfa_to_qrcode, mfa_read_token
 from n_utils.ndt import find_include, find_all_includes, include_dirs
 from n_utils.ndt_project import Project
-from n_utils.ndt_project import list_jobs, list_components
+from n_utils.ndt_project import list_jobs, list_components, upsert_codebuild_projects
 from n_utils.profile_util import update_profile
 from n_utils.tf_utils import pull_state, jmespath_var, flat_state
 from n_utils.utils import session_token, get_images, promote_image, \
@@ -673,6 +673,8 @@ def cli_create_account():
 
 def cli_load_parameters():
     """ Load parameters from infra*.properties files in the order:
+    branch.properties
+    [branch].properties
     infra.properties,
     infra-[branch].properties,
     [component]/infra.properties,
@@ -828,4 +830,35 @@ def cli_list_components():
     if args.json:
         print(json.dumps(ret, indent=2))
     else:
-        print("\n".join(ret))
\ No newline at end of file
+        print("\n".join(ret))
+
+def cli_upsert_codebuild_projects():
+    """ Creates or updates codebuild projects to deploy or bake ndt subcomponents in the current branch.
+
+    Parameters are read from properties files as described in 'ndt load-parameters -h'. To check all job paramters you
+    can run 'ndt list-jobs -e -j -b [current-branch]'
+    The only mandatory parameter is CODEBUILD_SERVICE_ROLE, which defines the role that the codebuild project assumes
+    for building.
+    Other parameters that affect jobs are:
+    * BUILD_JOB_NAME - name for the codebuild project
+    * NDT_VERSION - version to use to run bakes and deployments.
+        - Defaults to current version.
+        - You may also want to uses 'latest' to always run the latest released ndt version (only recommended for dev/testing workloads).
+    * BUILD_SPEC - file or yaml snippet to use as the build definition.
+        - See https://docs.aws.amazon.com/codebuild/latest/userguide/build-spec-ref.html
+        - subcomponent variables and special variables ${command}, ${component} and ${subcomponent} are available and will be substituted accordingly
+    * CODEBUILD_SOURCE_TYPE - one of BITBUCKET, CODECOMMIT, CODEPIPELINE, GITHUB, GITHUB_ENTERPRISE, NO_SOURCE, S3
+    * CODEBUILD_SOURCE_LOCATION - the location of the source code
+        - if either of the above is missing, then the source part of the build will be omitted
+    * CODEBUILD_EVENT_FILTER - the type of event to trigger the build.
+        - By default PULL_REQUEST_MERGED
+        - Other possible values: PUSH, PULL_REQUEST_CREATED, PULL_REQUEST_UPDATED and PULL_REQUEST_REOPENED
+    * NEEDS_DOCKER - if 'y' (by default on for docker bakes and missing otheriwise), docker server is started inside the container
+        - Needed for bakes and for example serverless python dockerized dependencies
+    """
+    parser = get_parser(formatter=argparse.RawDescriptionHelpFormatter)
+    parser.add_argument("-d", "--dry-run", action="store_true",
+                        help="Do not actually create or update projects, just print configuration")
+    argcomplete.autocomplete(parser)
+    args = parser.parse_args()
+    upsert_codebuild_projects(dry_run=args.dry_run)
